@@ -1,9 +1,9 @@
 package Apache;
 
 use vars qw($VERSION);
-use Apache::Constants;
+use Apache::Constants ();
 
-$VERSION = "1.05";
+$VERSION = "1.09";
 
 bootstrap Apache $VERSION;
 
@@ -20,7 +20,7 @@ sub content {
     my $ct = $r->header_in("Content-type");
     return unless $ct eq "application/x-www-form-urlencoded";
     my $buff;
-    $r->read_client_block($buff, $r->header_in("Content-length"));
+    $r->read($buff, $r->header_in("Content-length"));
     parse_args(wantarray, $buff);
 }
 
@@ -29,6 +29,41 @@ sub args {
     parse_args(wantarray, $r->query_string);
 }
 
+sub cgi_var {
+    my($r, $key) = @_;
+    my $val = $r->cgi_env($key);
+    return $val;
+}
+
+sub read {
+    my($r, $bufsiz) = @_[0,2];
+    my($nrd, $buf, $total);
+    $r->hard_timeout("Apache->read");
+
+    while($bufsiz) {
+	$nrd = $r->read_client_block($buf, $bufsiz);
+	if($nrd > 0) {
+	    $bufsiz -= $nrd;
+	    $total += $nrd;
+	    $_[1] .= $buf;
+	    next if $bufsiz;
+	    last;
+	}
+	else {
+	    $_[1] = undef;
+	}
+    }
+    $r->kill_timeout;
+    return $total;
+}
+
+sub print {
+    my($r) = shift;
+    $r->hard_timeout("Apache->print");
+    $r->write_client(@_);
+    $r->kill_timeout;
+}
+
 sub send_cgi_header {
     my($r, $headers) = @_;
     my $dlm = "\015?\012"; #a bit borrowed from LWP::UserAgent
@@ -214,7 +249,11 @@ Read from the entity body sent by the client.  Example of use:
 
 =item $r->read($buf, $bytes_to_read)
 
-Friendly alias for $r->read_client_block()
+This method uses read_client_block() to read data from the client, 
+looping until it gets all of C<$bytes_to_read> or a timeout happens.
+
+In addition, this method sets a timeout before reading with
+C<$r->hard_timeout>
 
 =item $r->get_remote_host
 
@@ -411,7 +450,8 @@ $r->send_http_header.
 
 =item $r->print()
 
-Friendly alias for $r->write_client()
+This method sends data to the client with C<$r->write_client>, but first
+sets a timeout before sending with C<$r->hard_timeout>.
 
 =item $r->send_fd( $filehandle )
 
@@ -431,6 +471,53 @@ telling the client. For instance:
 
 =back
 
+=head1 SERVER CORE FUNCTIONS
+
+=over 4
+
+=item $r->soft_timeout($message)
+
+=item $r->hard_timeout($message)
+
+=item $r->kill_timeout
+
+=item $r->reset_timeout
+
+(Documentation borrowed from http_main.h)
+
+There are two functions which modules can call to trigger a timeout
+(with the per-virtual-server timeout duration); these are hard_timeout
+and soft_timeout.
+
+The difference between the two is what happens when the timeout
+expires (or earlier than that, if the client connection aborts) ---
+a soft_timeout just puts the connection to the client in an
+"aborted" state, which will cause http_protocol.c to stop trying to
+talk to the client, but otherwise allows the code to continue normally.
+hard_timeout(), by contrast, logs the request, and then aborts it
+completely --- longjmp()ing out to the accept() loop in http_main.
+Any resources tied into the request's resource pool will be cleaned up;
+everything that isn't will leak.
+
+soft_timeout() is recommended as a general rule, because it gives your
+code a chance to clean up.  However, hard_timeout() may be the most
+convenient way of dealing with timeouts waiting for some external
+resource other than the client, if you can live with the restrictions.
+
+When a hard timeout is in scope, critical sections can be guarded
+with block_alarms() and unblock_alarms() --- these are declared in
+alloc.c because they are most often used in conjunction with
+routines to allocate something or other, to make sure that the
+cleanup does get registered before any alarm is allowed to happen
+which might require it to be cleaned up; they * are, however,
+implemented in http_main.c.
+
+kill_timeout() will disarm either variety of timeout.
+
+reset_timeout() resets the timeout in progress.
+
+=back
+
 =head1 CGI SUPPORT
 
 We also provide some methods that make it easier to support the CGI
@@ -455,6 +542,17 @@ you can say:
      #do normal CGI stuff
   }
 
+When given a key => value pair, this will set an environment variable.
+
+ $r->cgi_env(REMOTE_GROUP => "camels");
+
+=item $r->cgi_var($key);
+
+Calls $r->cgi_env($key) in a scalar context to prevent the mistake
+of calling in a list context.
+
+    my $doc_root = $r->cgi_env('DOCUMENT_ROOT');
+
 =item $r->send_cgi_header()
 
 Take action on certain headers including I<Status:>, I<Location:> and
