@@ -15,7 +15,6 @@ my(%Config) = (
 
 sub handler {
     my($r) = @_;
-    return OK unless $r->is_initial_req; #only the first internal request
     my($key,$val);
     my $attr = {
 	DBType => 'SQL',
@@ -50,7 +49,7 @@ Apache::AuthenDBI - Authenticate via Perl DBI
  AuthType Basic
 
  #authenticate via DBI
- PerlAuthenHandler Apache::AuthenDBI
+ PerlAuthenHandler Apache::AuthenDBI::handler
 
  PerlSetVar AuthDBIDB     dbname
  PerlSetVar AuthDBIUser   username
